Crate kcr_autoscaling_k8s_io

Crate kcr_autoscaling_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the autoscaling.k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

autoscaling.k8s.io/v1

  • VerticalPodAutoscalerCheckpoint
  • VerticalPodAutoscaler

autoscaling.k8s.io/v1beta2

  • VerticalPodAutoscalerCheckpoint
  • VerticalPodAutoscaler

Modules

v1
v1beta2